/**
  ******************************************************************************
  * @file    stm8s_rst.h
  * @author  MCD Application Team
  * @version V2.1.0
  * @date    18-November-2011
  * @brief   This file contains all functions prototype and macros for the RST peripheral.
  ******************************************************************************
  */
// Define to prevent recursive inclusion -------------------------------------
#ifndef __STM8S_RST_H
#define __STM8S_RST_H

// Includes ------------------------------------------------------------------
#include "stm8s.h"

 // @addtogroup STM8S_StdPeriph_Driver

 // @addtogroup RST_Exported_Types
typedef enum {
  RST_FLAG_EMCF    = (uint8_t)0x10, /*!< EMC reset flag */
  RST_FLAG_SWIMF   = (uint8_t)0x08, /*!< SWIM reset flag */
  RST_FLAG_ILLOPF  = (uint8_t)0x04, /*!< Illigal opcode reset flag */
  RST_FLAG_IWDGF   = (uint8_t)0x02, /*!< Independent watchdog reset flag */
  RST_FLAG_WWDGF   = (uint8_t)0x01  /*!< Window watchdog reset flag */
}RST_Flag_TypeDef;


// Exported constants --------------------------------------------------------
// Exported macros -----------------------------------------------------------

 // @addtogroup RST_Private_Macros

  // * @brief  Macro used by the assert function to check the different functions parameters.
  // * @brief  Macro used by the assert function to check the different RST flags.
#define IS_RST_FLAG_OK(FLAG) (((FLAG) == RST_FLAG_EMCF) || \
                              ((FLAG) == RST_FLAG_SWIMF)  ||\
                              ((FLAG) == RST_FLAG_ILLOPF) ||\
                              ((FLAG) == RST_FLAG_IWDGF)  ||\
                              ((FLAG) == RST_FLAG_WWDGF))


 // @addtogroup RST_Exported_functions
FlagStatus RST_GetFlagStatus(RST_Flag_TypeDef RST_Flag);
void RST_ClearFlag(RST_Flag_TypeDef RST_Flag);


#endif /* __STM8S_RST_H */

