/**
  ******************************************************************************
  * @file main.c
  * @brief Adjustable LED blinking speed using STM8S-DISCOVERY touch sensing key
  * Application example.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 25-NOV-2011
  ******************************************************************************
  *
  */

// Includes ------------------------------------------------------------------
#include "stm8s.h"

// Private functions ---------------------------------------------------------
// Global variables ----------------------------------------------------------
// Public functions ----------------------------------------------------------
void tempo (long t);
/**
  ******************************************************************************
  * @brief Main function.
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  ******************************************************************************
  */
void main(void)
{

  unsigned long ADC_result;
  unsigned char j;

  // Fmaster = 16MHz 
  CLK->CKDIVR = 0x00;

  // PB0, PB1, PB2 and PB3 in output push-pull low 
  GPIOB->DDR = 0x0F;
  GPIOB->CR1 = 0x0F;
  GPIOB->CR2 = 0x0F;
  GPIOB->ODR &= ~0x0F;

  // ADC configuration
  ADC1->CSR = 0x05; //seclect AIN5 (PD5) as channel to be converted
  ADC1->CR1 = 0x40; //Fadc = Fmaster/8 = 2MHz
  ADC1->CR2 = 0x08; //Right alignement


  while (1)
  {
    // ADC on
    ADC1->CR1 |= 0x01;
    // delay for ADC stabilization 7us
    for (j = 40;j > 0;j--);
    // start conversion
    ADC1->CR1 |= 0x01;
    // wait for end of conversion
    while (!(ADC1->CSR & 0x80));

    ADC_result =  ADC1->DRL;
    ADC_result |=  (ADC1->DRH << 8);

    // ADC conversion result scaled to be compliant with led temporisation 
    // Offset 4000 useful when ADC_result = 0 
    ADC_result = (ADC_result * 100) + 4000;

    GPIOB->ODR |= 0x01;
    tempo(ADC_result);

    GPIOB->ODR &= ~0x01;
    GPIOB->ODR |= 0x02;
    tempo(ADC_result);

    GPIOB->ODR &= ~0x02;
    GPIOB->ODR |= 0x04;
    tempo(ADC_result);

    GPIOB->ODR &= ~0x04;
    GPIOB->ODR |= 0x08;
    tempo(ADC_result);

    GPIOB->ODR &= ~0x08;
  }
}


/**
  ******************************************************************************
  * @brief Loop for temporisation
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  ******************************************************************************
  */
void tempo(long t)
{
  long i;
  for (i = 0;i < t;i++);
}

 // (c) 2008  STMicroelectronics *****************************

#ifdef USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval
  * None
  */
void assert_failed(u8* file, u32 line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {}
}
#endif

